@@ -1,10 +1,7 @@
-/*
- * This file Copyright (C) 2015 Mnemosyne LLC
- *
- * It may be used under the GNU GPL versions 2 or 3
- * or any future license endorsed by Mnemosyne LLC.
- *
- */
+// This file Copyright © 2015-2022 Mnemosyne LLC.
+// It may be used under GPLv2 (SPDX: GPL-2.0-only), GPLv3 (SPDX: GPL-3.0-only),
+// or any future license endorsed by Mnemosyne LLC.
+// License text can be found in the licenses/ folder.
 
 #pragma once
 
@@ -15,25 +12,23 @@
 #include "DBusInteropHelper.h"
 #endif
 
-class QAxObject;
 class QString;
-class QVariant;
 
 class InteropHelper
 {
 public:
     bool isConnected() const;
 
-    bool addMetainfo(QString const& metainfo);
+    bool addMetainfo(QString const& metainfo) const;
 
     static void initialize();
     static void registerObject(QObject* parent);
 
 private:
 #ifdef ENABLE_DBUS_INTEROP
-    DBusInteropHelper myDbusClient;
+    DBusInteropHelper dbus_client_ = {};
 #endif
 #ifdef ENABLE_COM_INTEROP
-    ComInteropHelper myComClient;
+    ComInteropHelper com_client_ = {};
 #endif
 };
