@@ -1,18 +1,18 @@
-/*
- * This file Copyright (C) 2012-2015 Mnemosyne LLC
- *
- * It may be used under the GNU GPL versions 2 or 3
- * or any future license endorsed by Mnemosyne LLC.
- *
- */
+// This file Copyright © 2012-2022 Mnemosyne LLC.
+// It may be used under GPLv2 (SPDX: GPL-2.0-only), GPLv3 (SPDX: GPL-3.0-only),
+// or any future license endorsed by Mnemosyne LLC.
+// License text can be found in the licenses/ folder.
 
 #pragma once
 
 #include <QObject>
 
+#include <libtransmission/tr-macros.h>
+
 class InteropObject : public QObject
 {
     Q_OBJECT
+    TR_DISABLE_COPY_MOVE(InteropObject)
 
 #ifdef ENABLE_DBUS_INTEROP
     Q_CLASSINFO("D-Bus Interface", "com.transmissionbt.Transmission")
@@ -27,9 +27,9 @@ class InteropObject : public QObject
 #endif
 
 public:
-    InteropObject(QObject* parent = nullptr);
+    explicit InteropObject(QObject* parent = nullptr);
 
 public slots:
-    bool PresentWindow();
-    bool AddMetainfo(QString const& metainfo);
+    bool PresentWindow() const;
+    bool AddMetainfo(QString const& metainfo) const;
 };
