@@ -1,37 +1,37 @@
-/*
- * This file Copyright (C) 2014-2016 Mnemosyne LLC
- *
- * It may be used under the GNU GPL versions 2 or 3
- * or any future license endorsed by Mnemosyne LLC.
- *
- */
+// This file Copyright © 2014-2022 Mnemosyne LLC.
+// It may be used under GPLv2 (SPDX: GPL-2.0-only), GPLv3 (SPDX: GPL-3.0-only),
+// or any future license endorsed by Mnemosyne LLC.
+// License text can be found in the licenses/ folder.
 
 #pragma once
 
+#include <cstdint> // int64_t
 #include <memory>
+#include <optional>
+#include <string_view>
 
 #include <QFuture>
 #include <QFutureInterface>
 #include <QHash>
+#include <QNetworkRequest>
 #include <QNetworkReply>
 #include <QObject>
 #include <QString>
 #include <QUrl>
 
 #include <libtransmission/transmission.h>
+
 #include <libtransmission/quark.h>
 #include <libtransmission/variant.h>
 
-class QByteArray;
 class QNetworkAccessManager;
 
-typedef std::shared_ptr<tr_variant> TrVariantPtr;
+using TrVariantPtr = std::shared_ptr<tr_variant>;
 Q_DECLARE_METATYPE(TrVariantPtr)
 
 extern "C"
 {
-struct evbuffer;
-struct tr_session;
+    struct tr_session;
 }
 
 struct RpcResponse
@@ -45,18 +45,15 @@ struct RpcResponse
 Q_DECLARE_METATYPE(QFutureInterface<RpcResponse>)
 
 // The response future -- the RPC engine returns one for each request made.
-typedef QFuture<RpcResponse> RpcResponseFuture;
+using RpcResponseFuture = QFuture<RpcResponse>;
 
 class RpcClient : public QObject
 {
     Q_OBJECT
+    TR_DISABLE_COPY_MOVE(RpcClient)
 
 public:
-    RpcClient(QObject* parent = nullptr);
-
-    virtual ~RpcClient()
-    {
-    }
+    explicit RpcClient(QObject* parent = nullptr);
 
     void stop();
     void start(tr_session* session);
@@ -66,7 +63,7 @@ public:
     QUrl const& url() const;
 
     RpcResponseFuture exec(tr_quark method, tr_variant* args);
-    RpcResponseFuture exec(char const* method, tr_variant* args);
+    RpcResponseFuture exec(std::string_view method, tr_variant* args);
 
 signals:
     void httpAuthenticationRequired();
@@ -74,6 +71,10 @@ signals:
     void dataSendProgress();
     void networkResponse(QNetworkReply::NetworkError code, QString const& message);
 
+private slots:
+    void networkRequestFinished(QNetworkReply* reply);
+    void localRequestFinished(TrVariantPtr response);
+
 private:
     RpcResponseFuture sendRequest(TrVariantPtr json);
     QNetworkAccessManager* networkAccessManager();
@@ -81,20 +82,18 @@ private:
 
     void sendNetworkRequest(TrVariantPtr json, QFutureInterface<RpcResponse> const& promise);
     void sendLocalRequest(TrVariantPtr json, QFutureInterface<RpcResponse> const& promise, int64_t tag);
-    int64_t parseResponseTag(tr_variant& response);
-    RpcResponse parseResponseData(tr_variant& response);
+    [[nodiscard]] int64_t parseResponseTag(tr_variant& response) const;
+    [[nodiscard]] RpcResponse parseResponseData(tr_variant& response) const;
 
-    static void localSessionCallback(tr_session* s, tr_variant* response, void* vself);
+    static void localSessionCallback(tr_session* s, tr_variant* response, void* vself) noexcept;
 
-private slots:
-    void networkRequestFinished(QNetworkReply* reply);
-    void localRequestFinished(TrVariantPtr response);
+    std::optional<QNetworkRequest> request_;
 
-private:
-    tr_session* mySession;
-    QString mySessionId;
-    QUrl myUrl;
-    QNetworkAccessManager* myNAM;
-    QHash<int64_t, QFutureInterface<RpcResponse>> myLocalRequests;
-    int64_t myNextTag;
+    tr_session* session_ = {};
+    QString session_id_;
+    QUrl url_;
+    QNetworkAccessManager* nam_ = {};
+    QHash<int64_t, QFutureInterface<RpcResponse>> local_requests_;
+    int64_t next_tag_ = {};
+    bool const verbose_ = qEnvironmentVariableIsSet("TR_RPC_VERBOSE");
 };
