@@ -1,15 +1,14 @@
-/*
- * This file Copyright (C) 2009-2015 Mnemosyne LLC
- *
- * It may be used under the GNU GPL versions 2 or 3
- * or any future license endorsed by Mnemosyne LLC.
- *
- */
+// This file Copyright © 2009-2022 Mnemosyne LLC.
+// It may be used under GPLv2 (SPDX: GPL-2.0-only), GPLv3 (SPDX: GPL-3.0-only),
+// or any future license endorsed by Mnemosyne LLC.
+// License text can be found in the licenses/ folder.
 
 #pragma once
 
 #include <QItemDelegate>
 
+#include <libtransmission/tr-macros.h>
+
 class QStyle;
 
 class Session;
@@ -18,11 +17,11 @@ struct TrackerInfo;
 class TrackerDelegate : public QItemDelegate
 {
     Q_OBJECT
+    TR_DISABLE_COPY_MOVE(TrackerDelegate)
 
 public:
-    TrackerDelegate(QObject* parent = nullptr) :
-        QItemDelegate(parent),
-        myShowMore(false)
+    explicit TrackerDelegate(QObject* parent = nullptr)
+        : QItemDelegate(parent)
     {
     }
 
@@ -39,5 +38,5 @@ protected:
     void drawTracker(QPainter*, QStyleOptionViewItem const&, TrackerInfo const&) const;
 
 private:
-    bool myShowMore;
+    bool show_more_ = false;
 };
