@@ -1,15 +1,47 @@
-#include "StdAfx.h"
+/*
+ * Copyright (c) 2010-2013 BitTorrent, Inc.
+ *
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
+ */
 
-#include "utypes.h"
-#include <assert.h>
 #include <stdlib.h>
+#include <assert.h>
+#include "utp.h"
+#include "utp_types.h"
 
 #ifdef WIN32
+	#define WIN32_LEAN_AND_MEAN
+	#include <windows.h>
+	#include <winsock2.h>
+	#include <ws2tcpip.h>
+#else //!WIN32
+	#include <time.h>
+	#include <sys/time.h>		// Linux needs both time.h and sys/time.h
+#endif
 
-#define WIN32_LEAN_AND_MEAN
-#include <windows.h>
-#include <winsock2.h>
-#include <ws2tcpip.h>
+#if defined(__APPLE__)
+	#include <mach/mach_time.h>
+#endif
+
+#include "utp_utils.h"
+
+#ifdef WIN32
 
 typedef ULONGLONG (WINAPI GetTickCount64Proc)(void);
 static GetTickCount64Proc *pt2GetTickCount64;
@@ -20,7 +52,7 @@ static uint64 startGetTickCount;
 // MSVC 6 standard doesn't like division with uint64s
 static double counterPerMicrosecond;
 
-uint64 UTGetTickCount64()
+static uint64 UTGetTickCount64()
 {
 	if (pt2GetTickCount64) {
 		return pt2GetTickCount64();
@@ -33,7 +65,7 @@ uint64 UTGetTickCount64()
 	return (uint64)GetTickCount();
 }
 
-void Time_Initialize()
+static void Time_Initialize()
 {
 	HMODULE kernel32 = GetModuleHandleA("kernel32.dll");
 	pt2GetTickCount64 = (GetTickCount64Proc*)GetProcAddress(kernel32, "GetTickCount64");
@@ -47,9 +79,9 @@ void Time_Initialize()
 	startGetTickCount = UTGetTickCount64();
 }
 
-int64 abs64(int64 x) { return x < 0 ? -x : x; }
+static int64 abs64(int64 x) { return x < 0 ? -x : x; }
 
-static uint64 GetMicroseconds()
+static uint64 __GetMicroseconds()
 {
 	static bool time_init = false;
 	if (!time_init) {
@@ -76,20 +108,22 @@ static uint64 GetMicroseconds()
 	return ret;
 }
 
+static inline uint64 UTP_GetMilliseconds()
+{
+	return GetTickCount();
+}
+
 #else //!WIN32
 
-#include <time.h>
-#include <sys/time.h>		// Linux needs both time.h and sys/time.h
-#include <stdlib.h>
-
-#include <unistd.h>
-#include <sys/socket.h>
-#include <arpa/inet.h>
+static inline uint64 UTP_GetMicroseconds(void);
+static inline uint64 UTP_GetMilliseconds()
+{
+	return UTP_GetMicroseconds() / 1000;
+}
 
 #if defined(__APPLE__)
-#include <mach/mach_time.h>
 
-static uint64 GetMicroseconds()
+static uint64 __GetMicroseconds()
 {
 	// http://developer.apple.com/mac/library/qa/qa2004/qa1398.html
 	// http://www.macresearch.org/tutorial_performance_and_time
@@ -97,59 +131,74 @@ static uint64 GetMicroseconds()
 	static uint64_t start_tick = 0;
 	uint64_t tick;
 	// Returns a counter in some fraction of a nanoseconds
-	tick = mach_absolute_time();  
+	tick = mach_absolute_time();
 	if (sTimebaseInfo.denom == 0) {
 		// Get the timer ratio to convert mach_absolute_time to nanoseconds
-		mach_timebase_info(&sTimebaseInfo); 
+		mach_timebase_info(&sTimebaseInfo);
 		start_tick = tick;
 	}
 	// Calculate the elapsed time, convert it to microseconds and return it.
 	return ((tick - start_tick) * sTimebaseInfo.numer) / (sTimebaseInfo.denom * 1000);
 }
 
-#else //!__APPLE__
+#else // !__APPLE__
+
+#if ! (defined(_POSIX_TIMERS) && _POSIX_TIMERS > 0 && defined(CLOCK_MONOTONIC))
+    #pragma message ("Using non-monotonic function gettimeofday() in UTP_GetMicroseconds()")
+#endif
 
 /* Unfortunately, #ifdef CLOCK_MONOTONIC is not enough to make sure that
    POSIX clocks work -- we could be running a recent libc with an ancient
    kernel (think OpenWRT). -- jch */
 
-static uint64_t GetMicroseconds()
+static uint64_t __GetMicroseconds()
 {
-	static int have_posix_clocks = -1;
-	int rc;
+	struct timeval tv;
 
-#if defined(_POSIX_TIMERS) && _POSIX_TIMERS > 0 && defined(CLOCK_MONOTONIC)
-	if (have_posix_clocks < 0) {
-		struct timespec ts;
-		rc = clock_gettime(CLOCK_MONOTONIC, &ts);
-		if (rc < 0) {
-			have_posix_clocks = 0;
-		} else {
-			have_posix_clocks = 1;
+	#if defined(_POSIX_TIMERS) && _POSIX_TIMERS > 0 && defined(CLOCK_MONOTONIC)
+		static int have_posix_clocks = -1;
+		int rc;
+
+		if (have_posix_clocks < 0) {
+			struct timespec ts;
+			rc = clock_gettime(CLOCK_MONOTONIC, &ts);
+			if (rc < 0) {
+				have_posix_clocks = 0;
+			} else {
+				have_posix_clocks = 1;
+			}
 		}
-	}
 
-	if (have_posix_clocks) {
-		struct timespec ts;
-		rc = clock_gettime(CLOCK_MONOTONIC, &ts);
-		return uint64(ts.tv_sec) * 1000000 + ts.tv_nsec / 1000;
-	}
-#endif
-	{
-		struct timeval tv;
-		rc = gettimeofday(&tv, NULL);
-		return uint64(tv.tv_sec) * 1000000 + tv.tv_usec;
-	}
+		if (have_posix_clocks) {
+			struct timespec ts;
+			rc = clock_gettime(CLOCK_MONOTONIC, &ts);
+			return uint64(ts.tv_sec) * 1000000 + uint64(ts.tv_nsec) / 1000;
+		}
+	#endif
+
+	gettimeofday(&tv, NULL);
+	return uint64(tv.tv_sec) * 1000000 + tv.tv_usec;
 }
+
 #endif //!__APPLE__
 
 #endif //!WIN32
 
-uint64 UTP_GetMicroseconds()
+/*
+ * Whew.  Okay.  After that #ifdef maze above, we now know we have a working
+ * __GetMicroseconds() implementation on all platforms.
+ * 
+ * Because there are a number of assertions in libutp that will cause a crash
+ * if monotonic time isn't monotonic, now apply some safety checks.  While in
+ * principle we're already protecting ourselves in cases where non-monotonic
+ * time is likely to happen, this protects all versions.
+ */
+
+static inline uint64 UTP_GetMicroseconds()
 {
 	static uint64 offset = 0, previous = 0;
 
-	uint64 now = GetMicroseconds() + offset;
+	uint64 now = __GetMicroseconds() + offset;
 	if (previous > now) {
 		/* Eek! */
 		offset += previous - now;
@@ -159,12 +208,6 @@ uint64 UTP_GetMicroseconds()
 	return now;
 }
 
-uint32 UTP_GetMilliseconds()
-{
-	return UTP_GetMicroseconds() / 1000;
-}
-
-
 #define ETHERNET_MTU 1500
 #define IPV4_HEADER_SIZE 20
 #define IPV6_HEADER_SIZE 40
@@ -186,25 +229,26 @@ uint32 UTP_GetMilliseconds()
 #define UDP_IPV6_MTU (ETHERNET_MTU - IPV6_HEADER_SIZE - UDP_HEADER_SIZE - GRE_HEADER_SIZE - PPPOE_HEADER_SIZE - MPPE_HEADER_SIZE - FUDGE_HEADER_SIZE)
 #define UDP_TEREDO_MTU (TEREDO_MTU - IPV6_HEADER_SIZE - UDP_HEADER_SIZE)
 
-uint16 UTP_GetUDPMTU(const struct sockaddr *remote, socklen_t remotelen)
-{
+uint64 utp_default_get_udp_mtu(utp_callback_arguments *args) {
 	// Since we don't know the local address of the interface,
 	// be conservative and assume all IPv6 connections are Teredo.
-	return remote->sa_family == AF_INET6 ? UDP_TEREDO_MTU : UDP_IPV4_MTU;
+	return (args->u1.address->sa_family == AF_INET6) ? UDP_TEREDO_MTU : UDP_IPV4_MTU;
 }
 
-uint16 UTP_GetUDPOverhead(const struct sockaddr *remote, socklen_t remotelen)
-{
+uint64 utp_default_get_udp_overhead(utp_callback_arguments *args) {
 	// Since we don't know the local address of the interface,
 	// be conservative and assume all IPv6 connections are Teredo.
-	return remote->sa_family == AF_INET6 ? UDP_TEREDO_OVERHEAD : UDP_IPV4_OVERHEAD;
+	return (args->u1.address->sa_family == AF_INET6) ? UDP_TEREDO_OVERHEAD : UDP_IPV4_OVERHEAD;
 }
 
-uint32 UTP_Random()
-{
+uint64 utp_default_get_random(utp_callback_arguments * /*args*/) {
 	return rand();
 }
 
-void UTP_DelaySample(const struct sockaddr *remote, int sample_ms) {}
-size_t UTP_GetPacketSize(const struct sockaddr *remote) { return 1500; }
+uint64 utp_default_get_milliseconds(utp_callback_arguments * /*args*/) {
+	return UTP_GetMilliseconds();
+}
 
+uint64 utp_default_get_microseconds(utp_callback_arguments * /*args*/) {
+	return UTP_GetMicroseconds();
+}
